@@ -467,7 +467,7 @@ class OctoPrintNannyPlugin(
             device_fingerprint=None,
             device_cloudiot_name=None,
             device_id=None,
-            device_name=None,
+            device_name=platform.node(),
             device_private_key=None,
             device_public_key=None,
             device_serial=None,
@@ -551,7 +551,6 @@ class OctoPrintNannyPlugin(
                 self._settings.get(["device_fingerprint"]) is None,
                 self._settings.get(["device_id"]) is None,
                 self._settings.get(["device_serial"]) is None,
-                self._settings.get(["device_name"]) is None,
                 self._settings.get(["device_registered"]) is False,
                 self._settings.get(["device_url"]) is None,
                 self._settings.get(["device_cloudiot_name"]) is None,
